==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01IngressFluentImpl<A extends ACMEChallengeSolverHTTP01IngressFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01IngressFluent<A>{
  public ACMEChallengeSolverHTTP01IngressFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl(ACMEChallengeSolverHTTP01Ingress instance) {
    this.withClassName(instance.getClassName()); 
    this.withIngressTemplate(instance.getIngressTemplate()); 
    this.withName(instance.getName()); 
    this.withPodTemplate(instance.getPodTemplate()); 
    this.withServiceType(instance.getServiceType()); 
  }
  private String className;
  private ACMEChallengeSolverHTTP01IngressTemplateBuilder ingressTemplate;
  private String name;
  private ACMEChallengeSolverHTTP01IngressPodTemplateBuilder podTemplate;
  private String serviceType;
  public String getClassName() {
    return this.className;
  }
  public A withClassName(String className) {
    this.className=className; return (A) this;
  }
  public Boolean hasClassName() {
    return this.className != null;
  }
  
  /**
   * This method has been deprecated, please use method buildIngressTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressTemplate getIngressTemplate() {
    return this.ingressTemplate!=null ?this.ingressTemplate.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressTemplate buildIngressTemplate() {
    return this.ingressTemplate!=null ?this.ingressTemplate.build():null;
  }
  public A withIngressTemplate(ACMEChallengeSolverHTTP01IngressTemplate ingressTemplate) {
    _visitables.get("ingressTemplate").remove(this.ingressTemplate);
    if (ingressTemplate!=null){ this.ingressTemplate= new ACMEChallengeSolverHTTP01IngressTemplateBuilder(ingressTemplate); _visitables.get("ingressTemplate").add(this.ingressTemplate);} else { this.ingressTemplate = null; _visitables.get("ingressTemplate").remove(this.ingressTemplate); } return (A) this;
  }
  public Boolean hasIngressTemplate() {
    return this.ingressTemplate != null;
  }
  public ACMEChallengeSolverHTTP01IngressFluent.IngressTemplateNested<A> withNewIngressTemplate() {
    return new ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressFluent.IngressTemplateNested<A> withNewIngressTemplateLike(ACMEChallengeSolverHTTP01IngressTemplate item) {
    return new ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressFluent.IngressTemplateNested<A> editIngressTemplate() {
    return withNewIngressTemplateLike(getIngressTemplate());
  }
  public ACMEChallengeSolverHTTP01IngressFluent.IngressTemplateNested<A> editOrNewIngressTemplate() {
    return withNewIngressTemplateLike(getIngressTemplate() != null ? getIngressTemplate(): new ACMEChallengeSolverHTTP01IngressTemplateBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressFluent.IngressTemplateNested<A> editOrNewIngressTemplateLike(ACMEChallengeSolverHTTP01IngressTemplate item) {
    return withNewIngressTemplateLike(getIngressTemplate() != null ? getIngressTemplate(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPodTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressPodTemplate getPodTemplate() {
    return this.podTemplate!=null ?this.podTemplate.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplate buildPodTemplate() {
    return this.podTemplate!=null ?this.podTemplate.build():null;
  }
  public A withPodTemplate(ACMEChallengeSolverHTTP01IngressPodTemplate podTemplate) {
    _visitables.get("podTemplate").remove(this.podTemplate);
    if (podTemplate!=null){ this.podTemplate= new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(podTemplate); _visitables.get("podTemplate").add(this.podTemplate);} else { this.podTemplate = null; _visitables.get("podTemplate").remove(this.podTemplate); } return (A) this;
  }
  public Boolean hasPodTemplate() {
    return this.podTemplate != null;
  }
  public ACMEChallengeSolverHTTP01IngressFluent.PodTemplateNested<A> withNewPodTemplate() {
    return new ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressFluent.PodTemplateNested<A> withNewPodTemplateLike(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
    return new ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressFluent.PodTemplateNested<A> editPodTemplate() {
    return withNewPodTemplateLike(getPodTemplate());
  }
  public ACMEChallengeSolverHTTP01IngressFluent.PodTemplateNested<A> editOrNewPodTemplate() {
    return withNewPodTemplateLike(getPodTemplate() != null ? getPodTemplate(): new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressFluent.PodTemplateNested<A> editOrNewPodTemplateLike(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
    return withNewPodTemplateLike(getPodTemplate() != null ? getPodTemplate(): item);
  }
  public String getServiceType() {
    return this.serviceType;
  }
  public A withServiceType(String serviceType) {
    this.serviceType=serviceType; return (A) this;
  }
  public Boolean hasServiceType() {
    return this.serviceType != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEChallengeSolverHTTP01IngressFluentImpl that = (ACMEChallengeSolverHTTP01IngressFluentImpl) o;
    if (className != null ? !className.equals(that.className) :that.className != null) return false;
    if (ingressTemplate != null ? !ingressTemplate.equals(that.ingressTemplate) :that.ingressTemplate != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (podTemplate != null ? !podTemplate.equals(that.podTemplate) :that.podTemplate != null) return false;
    if (serviceType != null ? !serviceType.equals(that.serviceType) :that.serviceType != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(className,  ingressTemplate,  name,  podTemplate,  serviceType,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (className != null) { sb.append("className:"); sb.append(className + ","); }
    if (ingressTemplate != null) { sb.append("ingressTemplate:"); sb.append(ingressTemplate + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (podTemplate != null) { sb.append("podTemplate:"); sb.append(podTemplate + ","); }
    if (serviceType != null) { sb.append("serviceType:"); sb.append(serviceType); }
    sb.append("}");
    return sb.toString();
  }
  class IngressTemplateNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressTemplateFluentImpl<ACMEChallengeSolverHTTP01IngressFluent.IngressTemplateNested<N>> implements ACMEChallengeSolverHTTP01IngressFluent.IngressTemplateNested<N>,Nested<N>{
    IngressTemplateNestedImpl(ACMEChallengeSolverHTTP01IngressTemplate item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressTemplateBuilder(this, item);
    }
    IngressTemplateNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressTemplateBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressTemplateBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressFluentImpl.this.withIngressTemplate(builder.build());
    }
    public N endIngressTemplate() {
      return and();
    }
    
  }
  class PodTemplateNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl<ACMEChallengeSolverHTTP01IngressFluent.PodTemplateNested<N>> implements ACMEChallengeSolverHTTP01IngressFluent.PodTemplateNested<N>,Nested<N>{
    PodTemplateNestedImpl(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(this, item);
    }
    PodTemplateNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressPodTemplateBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressFluentImpl.this.withPodTemplate(builder.build());
    }
    public N endPodTemplate() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01IngressFluentImpl<A extends ACMEChallengeSolverHTTP01IngressFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01IngressFluent<A>{
  public ACMEChallengeSolverHTTP01IngressFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl(ACMEChallengeSolverHTTP01Ingress instance) {
    if (instance != null) {
      this.withClassName(instance.getClassName());
      this.withIngressTemplate(instance.getIngressTemplate());
      this.withName(instance.getName());
      this.withPodTemplate(instance.getPodTemplate());
      this.withServiceType(instance.getServiceType());
    }
  }
  private String className;
  private ACMEChallengeSolverHTTP01IngressTemplateBuilder ingressTemplate;
  private String name;
  private ACMEChallengeSolverHTTP01IngressPodTemplateBuilder podTemplate;
  private String serviceType;
  public String getClassName() {
    return this.className;
  }
  public A withClassName(String className) {
    this.className=className; return (A) this;
  }
  public Boolean hasClassName() {
    return this.className != null;
  }
  
  /**
   * This method has been deprecated, please use method buildIngressTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressTemplate getIngressTemplate() {
    return this.ingressTemplate!=null ?this.ingressTemplate.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressTemplate buildIngressTemplate() {
    return this.ingressTemplate!=null ?this.ingressTemplate.build():null;
  }
  public A withIngressTemplate(ACMEChallengeSolverHTTP01IngressTemplate ingressTemplate) {
    _visitables.get("ingressTemplate").remove(this.ingressTemplate);
    if (ingressTemplate!=null){ this.ingressTemplate= new ACMEChallengeSolverHTTP01IngressTemplateBuilder(ingressTemplate); _visitables.get("ingressTemplate").add(this.ingressTemplate);} else { this.ingressTemplate = null; _visitables.get("ingressTemplate").remove(this.ingressTemplate); } return (A) this;
  }
  public Boolean hasIngressTemplate() {
    return this.ingressTemplate != null;
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNested<A> withNewIngressTemplate() {
    return new ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNested<A> withNewIngressTemplateLike(ACMEChallengeSolverHTTP01IngressTemplate item) {
    return new ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNested<A> editIngressTemplate() {
    return withNewIngressTemplateLike(getIngressTemplate());
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNested<A> editOrNewIngressTemplate() {
    return withNewIngressTemplateLike(getIngressTemplate() != null ? getIngressTemplate(): new ACMEChallengeSolverHTTP01IngressTemplateBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNested<A> editOrNewIngressTemplateLike(ACMEChallengeSolverHTTP01IngressTemplate item) {
    return withNewIngressTemplateLike(getIngressTemplate() != null ? getIngressTemplate(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPodTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressPodTemplate getPodTemplate() {
    return this.podTemplate!=null ?this.podTemplate.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplate buildPodTemplate() {
    return this.podTemplate!=null ?this.podTemplate.build():null;
  }
  public A withPodTemplate(ACMEChallengeSolverHTTP01IngressPodTemplate podTemplate) {
    _visitables.get("podTemplate").remove(this.podTemplate);
    if (podTemplate!=null){ this.podTemplate= new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(podTemplate); _visitables.get("podTemplate").add(this.podTemplate);} else { this.podTemplate = null; _visitables.get("podTemplate").remove(this.podTemplate); } return (A) this;
  }
  public Boolean hasPodTemplate() {
    return this.podTemplate != null;
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNested<A> withNewPodTemplate() {
    return new ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNested<A> withNewPodTemplateLike(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
    return new ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNested<A> editPodTemplate() {
    return withNewPodTemplateLike(getPodTemplate());
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNested<A> editOrNewPodTemplate() {
    return withNewPodTemplateLike(getPodTemplate() != null ? getPodTemplate(): new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNested<A> editOrNewPodTemplateLike(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
    return withNewPodTemplateLike(getPodTemplate() != null ? getPodTemplate(): item);
  }
  public String getServiceType() {
    return this.serviceType;
  }
  public A withServiceType(String serviceType) {
    this.serviceType=serviceType; return (A) this;
  }
  public Boolean hasServiceType() {
    return this.serviceType != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressFluentImpl that = (ACMEChallengeSolverHTTP01IngressFluentImpl) o;
    if (!java.util.Objects.equals(className, that.className)) return false;

    if (!java.util.Objects.equals(ingressTemplate, that.ingressTemplate)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(podTemplate, that.podTemplate)) return false;

    if (!java.util.Objects.equals(serviceType, that.serviceType)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(className,  ingressTemplate,  name,  podTemplate,  serviceType,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (className != null) { sb.append("className:"); sb.append(className + ","); }
    if (ingressTemplate != null) { sb.append("ingressTemplate:"); sb.append(ingressTemplate + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (podTemplate != null) { sb.append("podTemplate:"); sb.append(podTemplate + ","); }
    if (serviceType != null) { sb.append("serviceType:"); sb.append(serviceType); }
    sb.append("}");
    return sb.toString();
  }
  class IngressTemplateNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressTemplateFluentImpl<ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNested<N>> implements ACMEChallengeSolverHTTP01IngressFluentImpl.IngressTemplateNested<N>,Nested<N>{
    IngressTemplateNestedImpl(ACMEChallengeSolverHTTP01IngressTemplate item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressTemplateBuilder(this, item);
    }
    IngressTemplateNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressTemplateBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressTemplateBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressFluentImpl.this.withIngressTemplate(builder.build());
    }
    public N endIngressTemplate() {
      return and();
    }
    
  }
  class PodTemplateNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl<ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNested<N>> implements ACMEChallengeSolverHTTP01IngressFluentImpl.PodTemplateNested<N>,Nested<N>{
    PodTemplateNestedImpl(ACMEChallengeSolverHTTP01IngressPodTemplate item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(this, item);
    }
    PodTemplateNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressPodTemplateBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressFluentImpl.this.withPodTemplate(builder.build());
    }
    public N endPodTemplate() {
      return and();
    }
    
  }
  
}
